@@ -1,22 +1,21 @@
 package Lingua::ID::Number::Format::MixWithWords;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-06-14'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
-use Lingua::Base::Number::Format::MixWithWords;
 use parent qw(Lingua::Base::Number::Format::MixWithWords);
 require Lingua::EN::Number::Format::MixWithWords;
 
-use Exporter::Lite;
 use Math::Round qw(nearest);
 use Number::Format;
 use POSIX qw(floor log10);
 use Perinci::Sub::Util qw(gen_modified_sub);
 
+use Exporter qw(import);
 our @EXPORT_OK = qw(format_number_mix);
 
 our %SPEC;
@@ -91,7 +90,7 @@ Lingua::ID::Number::Format::MixWithWords - Format number to a mixture of numbers
 
 =head1 VERSION
 
-This document describes version 0.06 of Lingua::ID::Number::Format::MixWithWords (from Perl distribution Lingua-ID-Number-Format-MixWithWords), released on 2015-09-03.
+This document describes version 0.07 of Lingua::ID::Number::Format::MixWithWords (from Perl distribution Lingua-ID-Number-Format-MixWithWords), released on 2016-06-14.
 
 =head1 SYNOPSIS
 
@@ -113,6 +112,8 @@ formatted like a normal number.
 
 Format number to a mixture of numbers and words (e.g. "12,3 juta").
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -142,14 +143,6 @@ Can be negative, e.g. -1 to round to nearest 10, -2 to nearest 100, and so on.
 
 Return value:  (any)
 
-=head1 SEE ALSO
-
-L<Lingua::ID::Nums2Words>
-
-L<Lingua::EN::Number::Format::MixWithWords>
-
-L<Number::Format>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Lingua-ID-Number-Format-MixWithWords>.
@@ -166,13 +159,21 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Lingua::ID::Nums2Words>
+
+L<Lingua::EN::Number::Format::MixWithWords>
+
+L<Number::Format>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
